@@ -1,5 +1,5 @@
 /*
- $Id: lfe.h 1959 2016-04-10 05:48:28Z sgaure $
+ $Id: lfe.h 1991 2016-04-14 15:56:45Z sgaure $
 */
 
 #include "config.h"
@@ -139,7 +139,8 @@ SEXP MY_dsyr2k(SEXP inbeta, SEXP inC, SEXP inalpha, SEXP inA, SEXP inB);
 SEXP MY_sandwich(SEXP inalpha, SEXP inbread, SEXP inmeat);
 SEXP MY_address(SEXP x);
 SEXP MY_named(SEXP x, SEXP n);
-//SEXP MY_setnamed(SEXP x, SEXP n);
+SEXP Crowsum(SEXP Rmat, SEXP Rfactor, SEXP Rmean);
+
 // SEXP MY_ppf(SEXP flist, SEXP Rtype);
 SEXP df_string;
 int LFE_GLOBAL_THREADS;
